%% An example to simplify an iv-bolus 3-CMT PK model of midazolam 
%% These files were created by Shan Pan, Vittal Shivva and Stephen Duffull
%% Dec 2014
%% DO NOT EDIT THIS FILE
%% This file calls three other files which perform various jobs of model simplification of this example model

clear all
close all
tic


%% Set Design variables
% refer to slide # 18

Dose = 5;  % unit: mg, iv bolus

TT = [0:2:360];  % unit: min, 0-360 mins with a time step of every 2 mins  

IC=[Dose; 
    0
    0];  % initial conditions for each state (here initial conditions are defined as amounts)


%% Get model and parameter values
% refer to slide # 21

Model_parameter_values


%% Compute concentrations from the original model

AMT = ME_solution(K,IC,TT);
Conc = AMT(1,:)./V1;


%% Choose a lumping matrix
% refer to slides # 11, 12 & 13

Lumping_matrix ;  % Call the lumping matrix to create a simplified version of the model by lumping some of the states

[m,n] = size(M);  % size of the lumping matrix

Minv=pinv(M);     % Pseudoinverse of the lumping matrix
 % if using Freemat (ver 4.2) then write as Minv=(pinv(M)')'

K_hat=M*K*Minv;   % K matrix (parameter matrix) in the lumped model

IC_hat=M*IC;      % Initial conditions of the lumped states in the lumped matrix


%% Compute concentrations from lumped model

AMT_hat = ME_solution(K_hat,IC_hat,TT); 
Conc_hat = AMT_hat(1,:)./V1;


%% outputs 

% original model
figure (1)
subplot(1,2,1) % Concentration in central CMT
plot(TT,Conc,'b-','linewidth',2) % add x and y labels & modify label fontsize
xlabel('Time (min)','fontsize',24)
ylabel('Conc in central compartment (mg/L)','fontsize',24) % modify axis fontsize
set(gca,'fontsize',20)

% Profile of original model on semilogorithmic scale
subplot(1,2,2) % Concentration in central CMT (on log scale)
plot(TT,log(Conc),'b--','linewidth',2) % add x and y labels & modify label fontsize
xlabel('Time (min)','fontsize',24)
ylabel('Log Conc in central compartment (mg/L)','fontsize',24) % modify axis fontsize
set(gca,'fontsize',20)

ha = axes('Position',[0 0 1 1],'Xlim',[0 1],'Ylim',[0 1],'Box','off','Visible','off','Units','normalized','clipping','off');
text(0.5, 1,'\bf Original model','fontsize',20,'HorizontalAlignment','center','VerticalAlignment', 'top');

% lumped model
figure (2)
subplot(1,2,1) % Concentration in central CMT
plot(TT,Conc_hat,'r--','LineWidth',2) % add x and y labels & modify label fontsize
xlabel('Time (min)','fontsize',24)
ylabel('Conc in central compartment (mg/L)','fontsize',24) % modify axis fontsize
set(gca,'fontsize',20)

% Profile of lumped model on semilogorithmic scale
subplot(1,2,2) % Concentration in central CMT (on log scale)
plot(TT,log(Conc_hat),'r--','LineWidth',2) % add x and y labels & modify label fontsize
xlabel('Time (min)','fontsize',24)
ylabel('Log Conc in central compartment (mg/L)','fontsize',24); % modify axis fontsize
set(gca,'fontsize',20)

ha = axes('Position',[0 0 1 1],'Xlim',[0 1],'Ylim',[0 1],'Box','off','Visible','off','Units','normalized','clipping','off');
text(0.5, 1,'\bf Lumped model','fontsize',20,'HorizontalAlignment','center','VerticalAlignment', 'top');

% Percent relative difference between both models
figure(3)
subplot(1,2,1)
plot(TT,Conc,'b-','LineWidth',2); 
hold on
plot(TT,Conc_hat,'r--','LineWidth',2);
xlabel('Time (min)','fontsize',24)
ylabel('Conc in central compartment (mg/mL)','fontsize',24)
set(gca,'fontsize',20)
hold off
legend('Original model','Lumped model')

subplot(1,2,2) % difference in central concentration VS. time
difference_percent = ((Conc-Conc_hat)./Conc)*100; % calculate difference in central concentration between both models, unit: %
plot(TT,difference_percent,'linewidth',2)
xlabel('Time (min)','fontsize',24);
ylabel('Difference in Conc in central compartment (%)','fontsize',24) % modify axis fontsize
set(gca,'fontsize',20)

%%% Congratulations!!!! You have completed this example
%%% You can try lumping other combinations by changing only 'M' matrix in Lumping_matrix.m file
%%% You donot need to change anything else anywhere in any other file

toc 